==> download.php?FileName=terralib-5.2.3-ubuntu-16.04.tar.gz: opt/terralib/5.2.3/include/terralib/geometry/Point.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/geometry/Point.h

  \brief A point with x and y coordinate values.
*/

#ifndef __TERRALIB_GEOMETRY_INTERNAL_POINT_H
#define __TERRALIB_GEOMETRY_INTERNAL_POINT_H

// TerraLib
#include "Geometry.h"

namespace te
{
  namespace gm
  {
    /*!
      \class Point

      \brief A point with x and y coordinate values.

      \ingroup geometry

      \sa Geometry,
          AbstractPoint, PointM, PointZ, PointZM, PointKd,
          Curve, LineString, LinearRing, Line, CircularString, CompoundCurve,
          Surface, Polygon, Triangle, CurvePolygon, PolyhedralSurface, TIN,
          GeometryCollection, MultiSurface, MultiCurve,
          MultiPoint, MultiLineString, MultiPolygon
    */
    class TEGEOMEXPORT Point: public Geometry
    {
      public:

        TE_DEFINE_VISITABLE

        /** @name Initializer methods on geometric objects
          *  Methods for initializing a geometric object.
          */
        //@{

        /*!
        \brief It initializes the Geometry with the specified spatial reference system id and envelope.

        \param t    The internal type of the Geometry.
        \param srid The Spatial Reference System ID associated to the Geometry.
        \param mbr  The minimum bounding rectangle of this geometry (i.e., its envelope). It may be a NULL value.

        \note The Geometry will take the ownership of the given mbr.
        */
        Point(int srid = 0, GeomType t = te::gm::PointType, Envelope* mbr = 0);

        /*!
        \brief It initializes the Geometry with the specified spatial reference system id and envelope.

        \param t    The internal type of the Geometry.
        \param x    The Point x-coordinate value.
        \param y    The Point y-coordinate value.
        \param srid The Spatial Reference System ID associated to the Geometry.
        \param mbr  The minimum bounding rectangle of this geometry (i.e., its envelope). It may be a NULL value.

        \note The Geometry will take the ownership of the given mbr.
        */
        Point(const double& x, const double& y, int srid = 0, GeomType t = te::gm::PointType, Envelope* mbr = 0);

        /*!
          \brief Copy constructor.

          \param rhs The other geometry.
        */
        Point(const Point& rhs);

        /*!
          \brief Assignment operator.

          \param rhs The other geometry.

          \return A reference for this.
        */
        virtual Point& operator=(const Point& rhs);

        /*! \brief Virtual destructor. */
        virtual ~Point() { }

        //@}

        /** @name Re-Implementation from AbstractData
         *  Methods re-Implementated from AbstractData.
         */
        //@{

        /*!
          \brief It clones the point.

          \return A copy of the given point.

          \note The caller of this method will take the ownership of the returned point.

          \note The cloned point will not have the
                MBR computed. This will save time when you
                are just cloning a geometry and don't intend
                to waste time computing the bounding box.
                If you have another suggestion, please, let me know.
        */
        virtual te::dt::AbstractData* clone() const;

        //@}

        /** @name Point Specific Methods
        *  Specific methods that a point must implement.
        */
        //@{

        /*!
          \brief It returns the Point x-coordinate value.

          \return The x-coordinate value for this Point.
        */
        const double& getX() const { return m_x; }

        /*!
          \brief It sets the Point x-coordinate value.

          \param x The x-coordinate value for this Point.
        */
        void setX(const double& x) { m_x = x; }

        /*!
          \brief It returns the Point y-coordinate value.

          \return The y-coordinate value for this Point.
        */
        const double& getY() const { return m_y; }

        /*!
          \brief It sets the Point y-coordinate value.

          \param y The y-coordinate value for this Point.
        */
        void setY(const double& y) { m_y = y; }

        /*!
          \brief It returns the Point z-coordinate value, if it has one or DoubleNotANumber otherwise.

          \return The z-coordinate value for this Point.
        */
        const double& getZ() const { return m_z; }

        /*!
          \brief It sets the Point z-coordinate value.

          \param z The z-coordinate value for this Point.
        */
        void setZ(const double& z) { m_z = z; }

        /*!
          \brief It returns the Point m-coordinate value, if it has one or DoubleNotANumber otherwise.

          \return The m-coordinate value for this Point.
        */
        const double& getM() const { return m_m; }

        /*!
          \brief It sets the Point m-coordinate value.

          \param m The m-coordinate value for this Point.
        */
        void setM(const double& m) { m_m = m; };

        /*!
        \brief Less then operator.

        \param rhs The source object to be compared.

        \return True if the point have the coordinates values is less.
        */
        bool operator<(const Point& rhs);

        //@}

        /** @name Re-Implmentation of methods from Geometry class
        *  Re-Implmentation of basic methods from Geometry class.
        */
        //@{

        /*!
        \brief Points are 0-dimensional objects.

        \return te::gm::P (0-dimensional)
        */
        Dimensionality getDimension() const throw();

        /*!
        \brief The name of instantiable subtype is: Point.

        \return The name of instantiable subtype is: Point.
        */
        const std::string& getGeometryType() const throw();

        /*!
        \brief It sets the Spatial Reference System ID of the Point.

        \param srid The Spatial Reference System ID to be associated to the geometric object.

        \note TerraLib extended method.
        */
        void setSRID(int srid) throw();

        /*!
        \brief It converts the coordinate values of the point to the new spatial reference system.

        After calling this method the point will be associated to the new SRID.

        \param srid The new Spatial Reference System ID used to transform the coordinates of the point.

        \exception Exception It will throw an exception if it can not do the transformation.

        \note The point must be associated to a valid SRID before calling this method.

        \note If the point already has an associated MBR, this method will automatically update it (i. e. automatically recompute it).
        */
        void transform(int srid) throw(te::common::Exception);

        /*!
        \brief It computes the minimum bounding rectangle for the point.

        \param cascade For points this flag doesn't have effect.

        \note You can use this method in order to update the MBR of the point.

        \note TerraLib extended method.
        */
        void computeMBR(bool cascade) const throw();

        /*!
        \brief it returns the number of points (vertexes) in the geometry.

        \return The number of points (vertexes) in the geometry.

        \note TerraLib extended method.
        */
        std::size_t getNPoints() const throw() { return 1; }

        //@}

      protected:

        double m_x;   //!< The Point x-coordinate value.
        double m_y;   //!< The Point y-coordinate value.
        double m_z;   //!< The Point z-coordinate value.
        double m_m;   //!< The Point m-coordinate value.

        static const std::string sm_typeName; //!< Geometry type name for Point.
        static const double sm_notNumber;     //!< Just a special value to return in the case of a invalid Geometry.
    };

  } // end namespace gm
}   // end namespace te

#endif  // __TERRALIB_GEOMETRY_INTERNAL_POINT_H

==> download.php?FileName=terralib-5.3.0-ubuntu-16.04.tar.gz: opt/terralib/5.3.0/include/terralib/geometry/Point.h <==
/*  Copyright (C) 2008 National Institute For Space Research (INPE) - Brazil.

    This file is part of the TerraLib - a Framework for building GIS enabled applications.

    TerraLib is free software: you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published by
    the Free Software Foundation, either version 3 of the License,
    or (at your option) any later version.

    TerraLib is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public License
    along with TerraLib. See COPYING. If not, write to
    TerraLib Team at <terralib-team@terralib.org>.
 */

/*!
  \file terralib/geometry/Point.h

  \brief A point with x and y coordinate values.
*/

#ifndef __TERRALIB_GEOMETRY_INTERNAL_POINT_H
#define __TERRALIB_GEOMETRY_INTERNAL_POINT_H

// TerraLib
#include "Geometry.h"

namespace te
{
  namespace gm
  {
    /*!
      \class Point

      \brief A point with x and y coordinate values.

      \ingroup geometry

      \sa Geometry,
          AbstractPoint, PointM, PointZ, PointZM, PointKd,
          Curve, LineString, LinearRing, Line, CircularString, CompoundCurve,
          Surface, Polygon, Triangle, CurvePolygon, PolyhedralSurface, TIN,
          GeometryCollection, MultiSurface, MultiCurve,
          MultiPoint, MultiLineString, MultiPolygon
    */
    class TEGEOMEXPORT Point: public Geometry
    {
      public:

        TE_DEFINE_VISITABLE

        /** @name Initializer methods on geometric objects
          *  Methods for initializing a geometric object.
          */
        //@{

        /*!
        \brief It initializes the Geometry with the specified spatial reference system id and envelope.

        \param t    The internal type of the Geometry.
        \param srid The Spatial Reference System ID associated to the Geometry.
        \param mbr  The minimum bounding rectangle of this geometry (i.e., its envelope). It may be a NULL value.

        \note The Geometry will take the ownership of the given mbr.
        */
        Point(int srid = 0, GeomType t = te::gm::PointType, Envelope* mbr = 0);

        /*!
        \brief It initializes the Geometry with the specified spatial reference system id and envelope.

        \param t    The internal type of the Geometry.
        \param x    The Point x-coordinate value.
        \param y    The Point y-coordinate value.
        \param srid The Spatial Reference System ID associated to the Geometry.
        \param mbr  The minimum bounding rectangle of this geometry (i.e., its envelope). It may be a NULL value.

        \note The Geometry will take the ownership of the given mbr.
        */
        Point(const double& x, const double& y, int srid = 0, GeomType t = te::gm::PointType, Envelope* mbr = 0);

        /*!
          \brief Copy constructor.

          \param rhs The other geometry.
        */
        Point(const Point& rhs);

        /*!
          \brief Assignment operator.

          \param rhs The other geometry.

          \return A reference for this.
        */
        virtual Point& operator=(const Point& rhs);

        /*! \brief Virtual destructor. */
        virtual ~Point() { }

        //@}

        /** @name Re-Implementation from AbstractData
         *  Methods re-Implementated from AbstractData.
         */
        //@{

        /*!
          \brief It clones the point.

          \return A copy of the given point.

          \note The caller of this method will take the ownership of the returned point.

          \note The cloned point will not have the
                MBR computed. This will save time when you
                are just cloning a geometry and don't intend
                to waste time computing the bounding box.
                If you have another suggestion, please, let me know.
        */
        virtual te::dt::AbstractData* clone() const;

        //@}

        /** @name Point Specific Methods
        *  Specific methods that a point must implement.
        */
        //@{

        /*!
          \brief It returns the Point x-coordinate value.

          \return The x-coordinate value for this Point.
        */
        const double& getX() const { return m_x; }

        /*!
          \brief It sets the Point x-coordinate value.

          \param x The x-coordinate value for this Point.
        */
        void setX(const double& x) { m_x = x; }

        /*!
          \brief It returns the Point y-coordinate value.

          \return The y-coordinate value for this Point.
        */
        const double& getY() const { return m_y; }

        /*!
          \brief It sets the Point y-coordinate value.

          \param y The y-coordinate value for this Point.
        */
        void setY(const double& y) { m_y = y; }

        /*!
          \brief It returns the Point z-coordinate value, if it has one or DoubleNotANumber otherwise.

          \return The z-coordinate value for this Point.
        */
        const double& getZ() const { return m_z; }

        /*!
          \brief It sets the Point z-coordinate value.

          \param z The z-coordinate value for this Point.
        */
        void setZ(const double& z) { m_z = z; }

        /*!
          \brief It returns the Point m-coordinate value, if it has one or DoubleNotANumber otherwise.

          \return The m-coordinate value for this Point.
        */
        const double& getM() const { return m_m; }

        /*!
          \brief It sets the Point m-coordinate value.

          \param m The m-coordinate value for this Point.
        */
        void setM(const double& m) { m_m = m; }

        /*!
        \brief Less then operator.

        \param rhs The source object to be compared.

        \return True if the point have the coordinates values is less.
        */
        bool operator<(const Point& rhs);

        //@}

        /** @name Re-Implmentation of methods from Geometry class
        *  Re-Implmentation of basic methods from Geometry class.
        */
        //@{

        /*!
        \brief Points are 0-dimensional objects.

        \return te::gm::P (0-dimensional)
        */
        Dimensionality getDimension() const _NOEXCEPT_OP(true);

        /*!
        \brief The name of instantiable subtype is: Point.

        \return The name of instantiable subtype is: Point.
        */
        const std::string& getGeometryType() const _NOEXCEPT_OP(true);

        /*!
        \brief It sets the Spatial Reference System ID of the Point.

        \param srid The Spatial Reference System ID to be associated to the geometric object.

        \note TerraLib extended method.
        */
        void setSRID(int srid) _NOEXCEPT_OP(true);

        /*!
        \brief It converts the coordinate values of the point to the new spatial reference system.

        After calling this method the point will be associated to the new SRID.

        \param srid The new Spatial Reference System ID used to transform the coordinates of the point.

        \exception Exception It will throw an exception if it can not do the transformation.

        \note The point must be associated to a valid SRID before calling this method.

        \note If the point already has an associated MBR, this method will automatically update it (i. e. automatically recompute it).
        */
        void transform(int srid) _NOEXCEPT_OP(false);

        /*!
        \brief It computes the minimum bounding rectangle for the point.

        \param cascade For points this flag doesn't have effect.

        \note You can use this method in order to update the MBR of the point.

        \note TerraLib extended method.
        */
        void computeMBR(bool cascade) const _NOEXCEPT_OP(true);

        /*!
        \brief it returns the number of points (vertexes) in the geometry.

        \return The number of points (vertexes) in the geometry.

        \note TerraLib extended method.
        */
        std::size_t getNPoints() const _NOEXCEPT_OP(true){ return 1; }

        //@}

      protected:

        double m_x;   //!< The Point x-coordinate value.
        double m_y;   //!< The Point y-coordinate value.
        double m_z;   //!< The Point z-coordinate value.
        double m_m;   //!< The Point m-coordinate value.

        static const std::string sm_typeName; //!< Geometry type name for Point.
        static const double sm_notNumber;     //!< Just a special value to return in the case of a invalid Geometry.
    };

  } // end namespace gm
}   // end namespace te

#endif  // __TERRALIB_GEOMETRY_INTERNAL_POINT_H
